package com.cmvr.aima.service;

import java.util.List;
import com.cmvr.aima.domain.AimaPhone;

/**
 * 爱玛手机管理Service接口
 * 
 * @author cmvr-iot
 * @since 2026-06-22
 */
public interface IAimaPhoneService {
    /**
     * 查询爱玛手机管理
     * 
     * @param id 爱玛手机管理主键
     * @return 爱玛手机管理
     */
    AimaPhone selectAimaPhoneById(String id);

    /**
     * 查询爱玛手机管理列表
     * 
     * @param aimaPhone 爱玛手机管理
     * @return 爱玛手机管理集合
     */
    List<AimaPhone> selectAimaPhoneList(AimaPhone aimaPhone);

    /**
     * 新增爱玛手机管理
     * 
     * @param aimaPhone 爱玛手机管理
     * @return 结果
     */
    int insertAimaPhone(AimaPhone aimaPhone);

    /**
     * 修改爱玛手机管理
     * 
     * @param aimaPhone 爱玛手机管理
     * @return 结果
     */
    int updateAimaPhone(AimaPhone aimaPhone);

    /**
     * 批量删除爱玛手机管理
     * 
     * @param ids 需要删除的爱玛手机管理主键集合
     * @return 结果
     */
    int deleteAimaPhoneByIds(String[] ids);

    /**
     * 删除爱玛手机管理信息
     * 
     * @param id 爱玛手机管理主键
     * @return 结果
     */
    int deleteAimaPhoneById(String id);
}
